==> haskell-commonmark-0.2.6.1-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark
version:              0.2.6.1
visibility:           public
id:                   commonmark-0.2.6.1-JWIj5bBTmxAHvRT6OZmwg2
key:                  commonmark-0.2.6.1-JWIj5bBTmxAHvRT6OZmwg2
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides the core data types and functions
    for parsing commonmark (<https://spec.commonmark.org>).
    The parser is fully commonmark-compliant and passes the test
    suite.  It is designed to be customizable and easily extensible.
    To customize the output, create an AST, or support a new output
    format, one need only define some new typeclass instances.
    It is also easy to add new syntax elements or modify existing ones.

    Accurate information about source positions is available
    for all block and inline elements.  Thus the library can be
    used to create an accurate syntax highlighter or
    an editor with live preview.

    The parser has been designed for robust performance
    even in pathological cases that tend to cause stack overflows or
    exponential slowdowns in other parsers, with parsing speed that
    varies linearly with input length.

    Related packages:

    - commonmark-extensions (which defines a number of syntax extensions)
    - commonmark-pandoc (which allows using this parser to create a Pandoc
    structure)
    - commonmark-cli (a command-line tool for converting and
    syntax-highlighting commonmark documents)

category:             Text
abi:                  50a2fedd49fa4ba3d75c7795d17d7f8f
exposed:              True
exposed-modules:
    Commonmark Commonmark.Blocks Commonmark.Entity Commonmark.Html
    Commonmark.Inlines Commonmark.Parser Commonmark.ReferenceMap
    Commonmark.SourceMap Commonmark.Syntax Commonmark.Tag
    Commonmark.TokParsers Commonmark.Tokens Commonmark.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark
hs-libraries:         HScommonmark-0.2.6.1-JWIj5bBTmxAHvRT6OZmwg2
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unicode-data-0.6.0-3ALrdWImYUPBymKzUFECS2
    unicode-transforms-0.4.0.1-48s61tVtYpNDdAKWZ0R2Os

haddock-interfaces:   /usr/share/doc/haskell-commonmark/html/commonmark.haddock
haddock-html:         /usr/share/doc/haskell-commonmark/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-0.2.6.1-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark
version:              0.2.6.1
visibility:           public
id:                   commonmark-0.2.6.1-7KkCaWW0n6p9dRXTxjGU98
key:                  commonmark-0.2.6.1-7KkCaWW0n6p9dRXTxjGU98
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides the core data types and functions
    for parsing commonmark (<https://spec.commonmark.org>).
    The parser is fully commonmark-compliant and passes the test
    suite.  It is designed to be customizable and easily extensible.
    To customize the output, create an AST, or support a new output
    format, one need only define some new typeclass instances.
    It is also easy to add new syntax elements or modify existing ones.

    Accurate information about source positions is available
    for all block and inline elements.  Thus the library can be
    used to create an accurate syntax highlighter or
    an editor with live preview.

    The parser has been designed for robust performance
    even in pathological cases that tend to cause stack overflows or
    exponential slowdowns in other parsers, with parsing speed that
    varies linearly with input length.

    Related packages:

    - commonmark-extensions (which defines a number of syntax extensions)
    - commonmark-pandoc (which allows using this parser to create a Pandoc
    structure)
    - commonmark-cli (a command-line tool for converting and
    syntax-highlighting commonmark documents)

category:             Text
abi:                  6b1021f42404874176558f78cead9cbc
exposed:              True
exposed-modules:
    Commonmark Commonmark.Blocks Commonmark.Entity Commonmark.Html
    Commonmark.Inlines Commonmark.Parser Commonmark.ReferenceMap
    Commonmark.SourceMap Commonmark.Syntax Commonmark.Tag
    Commonmark.TokParsers Commonmark.Tokens Commonmark.Types

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/commonmark-0.2.6.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/commonmark-0.2.6.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/commonmark-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark
hs-libraries:         HScommonmark-0.2.6.1-7KkCaWW0n6p9dRXTxjGU98
depends:
    base-4.18.3.0 bytestring-0.11.5.4 containers-0.6.7 parsec-3.1.16.1
    text-2.0.2 transformers-0.6.1.0
    unicode-data-0.6.0-HbndOXBd9SeBTYxqeA0LRZ
    unicode-transforms-0.4.0.1-3tl6XWOY3Cd7TGJYhTRzE

haddock-interfaces:   /usr/share/doc/haskell-commonmark/html/commonmark.haddock
haddock-html:         /usr/share/doc/haskell-commonmark/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
